@@ -1,6 +1,8 @@
 cargo publish -p yazi-shared
 cargo publish -p yazi-config
+cargo publish -p yazi-proxy
 cargo publish -p yazi-adaptor
+cargo publish -p yazi-boot
 cargo publish -p yazi-scheduler
 cargo publish -p yazi-plugin
 cargo publish -p yazi-core
