@@ -1,13 +1,14 @@
+use yazi_proxy::CompletionProxy;
 use yazi_shared::{event::Cmd, render, InputError};
 
-use crate::{completion::Completion, input::Input};
+use crate::input::Input;
 
 pub struct Opt {
 	submit: bool,
 }
 
 impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { submit: c.named.contains_key("submit") } }
+	fn from(c: Cmd) -> Self { Self { submit: c.bool("submit") } }
 }
 impl From<bool> for Opt {
 	fn from(submit: bool) -> Self { Self { submit } }
@@ -18,7 +19,7 @@ impl Input {
 		let opt = opt.into() as Opt;
 
 		if self.completion {
-			Completion::_close();
+			CompletionProxy::close();
 		}
 
 		if let Some(cb) = self.callback.take() {
