@@ -8,9 +8,7 @@ pub struct Opt {
 }
 
 impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
-		Self { relative: c.named.contains_key("relative"), force: c.named.contains_key("force") }
-	}
+	fn from(c: Cmd) -> Self { Self { relative: c.bool("relative"), force: c.bool("force") } }
 }
 
 impl Manager {
