@@ -1,4 +1,3 @@
-use yazi_proxy::AppProxy;
 use yazi_shared::event::Cmd;
 
 use crate::manager::Manager;
@@ -7,7 +6,7 @@ impl Manager {
 	pub fn suspend(&mut self, _: Cmd) {
 		#[cfg(unix)]
 		tokio::spawn(async move {
-			AppProxy::stop().await;
+			yazi_proxy::AppProxy::stop().await;
 			unsafe { libc::raise(libc::SIGTSTP) };
 		});
 	}
