@@ -1,4 +1,4 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::{event::{Cmd, Data}, render};
 
 use crate::manager::Tabs;
 
@@ -7,20 +7,19 @@ pub struct Opt {
 }
 
 impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		Self { step: c.take_first().and_then(|s| s.parse().ok()).unwrap_or(0) }
-	}
+	fn from(c: Cmd) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 
 impl Tabs {
 	pub fn swap(&mut self, opt: impl Into<Opt>) {
 		let idx = self.absolute(opt.into().step);
-		if idx == self.idx {
+		if idx == self.cursor {
 			return;
 		}
 
-		self.items.swap(self.idx, idx);
+		self.items.swap(self.cursor, idx);
 		self.set_idx(idx);
+		self.reorder();
 		render!();
 	}
 }
