@@ -1,8 +1,9 @@
 use std::borrow::Cow;
 
+use yazi_proxy::ManagerProxy;
 use yazi_shared::{event::Cmd, fs::FilesOp, render};
 
-use crate::{folder::Folder, manager::Manager, tab::Tab, tasks::Tasks};
+use crate::{folder::Folder, manager::{Manager, LINKED}, tab::Tab, tasks::Tasks};
 
 pub struct Opt {
 	op: FilesOp,
@@ -11,12 +12,40 @@ pub struct Opt {
 impl TryFrom<Cmd> for Opt {
 	type Error = ();
 
-	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> { Ok(Self { op: c.take_data().ok_or(())? }) }
+	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
+		Ok(Self { op: c.take_any("op").ok_or(())? })
+	}
 }
 
 impl Manager {
+	pub fn update_files(&mut self, opt: impl TryInto<Opt>, tasks: &Tasks) {
+		let Ok(opt) = opt.try_into() else {
+			return;
+		};
+
+		let mut ops = vec![opt.op];
+		for u in LINKED.read().from_dir(ops[0].url()) {
+			ops.push(ops[0].chroot(u));
+		}
+
+		for op in ops {
+			let idx = self.tabs.cursor;
+			self.yanked.apply_op(&op);
+
+			for (_, tab) in self.tabs.iter_mut().enumerate().filter(|(i, _)| *i != idx) {
+				Self::update_tab(tab, Cow::Borrowed(&op), tasks);
+			}
+			Self::update_tab(self.active_mut(), Cow::Owned(op), tasks);
+		}
+
+		render!(self.yanked.catchup_revision(false));
+		self.active_mut().apply_files_attrs();
+	}
+
 	fn update_tab(tab: &mut Tab, op: Cow<FilesOp>, tasks: &Tasks) {
 		let url = op.url();
+		tab.selected.apply_op(&op);
+
 		if tab.current.cwd == *url {
 			Self::update_current(tab, op, tasks);
 		} else if matches!(&tab.parent, Some(p) if p.cwd == *url) {
@@ -56,8 +85,8 @@ impl Manager {
 			return;
 		}
 
-		Self::_hover(None); // Re-hover in next loop
-		Self::_update_paged(); // Update for paged files in next loop
+		ManagerProxy::hover(None); // Re-hover in next loop
+		ManagerProxy::update_paged(); // Update for paged files in next loop
 		if calc {
 			tasks.preload_sorted(&tab.current.files);
 		}
@@ -73,7 +102,7 @@ impl Manager {
 		}
 
 		if !foreign {
-			Self::_peek(true);
+			ManagerProxy::peek(true);
 		}
 	}
 
@@ -91,26 +120,4 @@ impl Manager {
 			tab.leave(());
 		}
 	}
-
-	pub fn update_files(&mut self, opt: impl TryInto<Opt>, tasks: &Tasks) {
-		let Ok(opt) = opt.try_into() else {
-			return;
-		};
-
-		let mut ops = vec![opt.op];
-		for u in self.watcher.linked.read().from_dir(ops[0].url()) {
-			ops.push(ops[0].chroot(u));
-		}
-
-		for op in ops {
-			let idx = self.tabs.idx;
-			for (_, tab) in self.tabs.iter_mut().enumerate().filter(|(i, _)| *i != idx) {
-				Self::update_tab(tab, Cow::Borrowed(&op), tasks);
-			}
-
-			Self::update_tab(self.active_mut(), Cow::Owned(op), tasks);
-		}
-
-		self.active_mut().apply_files_attrs();
-	}
 }
