@@ -11,20 +11,25 @@ pub struct Message {
 	pub level:   NotifyLevel,
 	pub timeout: Duration,
 
-	pub instant: Instant,
-	pub percent: u8,
+	pub instant:   Instant,
+	pub percent:   u8,
+	pub max_width: usize,
 }
 
 impl From<NotifyOpt> for Message {
 	fn from(opt: NotifyOpt) -> Self {
+		let title = opt.title.lines().next().unwrap_or_default();
+		let max_width = opt.content.lines().map(|s| s.width()).max().unwrap_or(0).max(title.width());
+
 		Self {
-			title:   opt.title,
+			title:   title.to_owned(),
 			content: opt.content,
 			level:   opt.level,
 			timeout: opt.timeout,
 
-			instant: Instant::now(),
-			percent: 0,
+			instant:   Instant::now(),
+			percent:   0,
+			max_width: max_width + NOTIFY_BORDER as usize,
 		}
 	}
 }
@@ -36,7 +41,11 @@ impl Message {
 			return 0; // In case we can't get the width of the terminal
 		}
 
-		let lines = (self.content.width() as f64 / width as f64).ceil();
-		lines as usize + NOTIFY_BORDER as usize
+		let mut lines = 0;
+		for line in self.content.lines() {
+			lines += (line.width() + 1).div_ceil(width as usize)
+		}
+
+		lines + NOTIFY_BORDER as usize
 	}
 }
