@@ -1,5 +1,5 @@
 use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::Cmd, fs::{expand_path, File, FilesOp, Url}};
+use yazi_shared::{event::{Cmd, Data}, fs::{expand_path, File, FilesOp, Url}};
 
 use crate::tab::Tab;
 
@@ -9,7 +9,7 @@ pub struct Opt {
 
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
-		let mut target = Url::from(c.take_first().unwrap_or_default());
+		let mut target = c.take_first().and_then(Data::into_url).unwrap_or_default();
 		if target.is_regular() {
 			target.set_path(expand_path(&target))
 		}
