@@ -1,3 +1,5 @@
+use std::borrow::Cow;
+
 use yazi_config::{open::Opener, popup::InputCfg};
 use yazi_proxy::{InputProxy, TasksProxy};
 use yazi_shared::event::Cmd;
@@ -7,15 +9,17 @@ use crate::tab::Tab;
 pub struct Opt {
 	run:     String,
 	block:   bool,
+	orphan:  bool,
 	confirm: bool,
 }
 
 impl From<Cmd> for Opt {
 	fn from(mut c: Cmd) -> Self {
 		Self {
-			run:     c.take_first().unwrap_or_default(),
-			block:   c.named.contains_key("block"),
-			confirm: c.named.contains_key("confirm"),
+			run:     c.take_first_str().unwrap_or_default(),
+			block:   c.bool("block"),
+			orphan:  c.bool("orphan"),
+			confirm: c.bool("confirm"),
 		}
 	}
 }
@@ -27,7 +31,7 @@ impl Tab {
 		}
 
 		let mut opt = opt.into() as Opt;
-		let selected = self.hovered_and_selected().into_iter().cloned().collect();
+		let selected = self.hovered_and_selected(true).cloned().collect();
 
 		tokio::spawn(async move {
 			if !opt.confirm || opt.run.is_empty() {
@@ -38,14 +42,17 @@ impl Tab {
 				}
 			}
 
-			TasksProxy::open_with(selected, Opener {
-				run:    opt.run,
-				block:  opt.block,
-				orphan: false,
-				desc:   Default::default(),
-				for_:   None,
-				spread: true,
-			});
+			TasksProxy::open_with(
+				selected,
+				Cow::Owned(Opener {
+					run:    opt.run,
+					block:  opt.block,
+					orphan: opt.orphan,
+					desc:   Default::default(),
+					for_:   None,
+					spread: true,
+				}),
+			);
 		});
 	}
 }
