@@ -9,7 +9,7 @@ impl Widget for Status {
 	fn render(self, area: ratatui::layout::Rect, buf: &mut ratatui::buffer::Buffer) {
 		let mut f = || {
 			let area = Rect::cast(&LUA, area)?;
-			let comp: Table = LUA.globals().get("Status")?;
+			let comp: Table = LUA.globals().raw_get("Status")?;
 			render_widgets(comp.call_method("render", area)?, buf);
 			Ok::<_, anyhow::Error>(())
 		};
