@@ -34,6 +34,7 @@ impl<'a> Executor<'a> {
 			};
 		}
 
+		on!(accept_payload);
 		on!(notify);
 		on!(plugin);
 		on!(plugin_do);
@@ -66,6 +67,7 @@ impl<'a> Executor<'a> {
 		on!(MANAGER, update_files, &self.app.cx.tasks);
 		on!(MANAGER, update_mimetype, &self.app.cx.tasks);
 		on!(MANAGER, update_paged, &self.app.cx.tasks);
+		on!(MANAGER, update_yanked);
 		on!(MANAGER, hover);
 		on!(MANAGER, peek);
 		on!(MANAGER, seek);
@@ -156,6 +158,7 @@ impl<'a> Executor<'a> {
 		on!(inspect);
 		on!(cancel);
 		on!(open_with);
+		on!(process_exec);
 
 		#[allow(clippy::single_match)]
 		match cmd.name.as_str() {
@@ -212,7 +215,7 @@ impl<'a> Executor<'a> {
 		on!(forward);
 
 		if cmd.name.as_str() == "complete" {
-			return if cmd.named.contains_key("trigger") {
+			return if cmd.bool("trigger") {
 				self.app.cx.completion.trigger(cmd)
 			} else {
 				self.app.cx.input.complete(cmd)
