@@ -39,17 +39,22 @@ async fn main() -> anyhow::Result<()> {
 
 	_ = fdlimit::raise_fd_limit();
 
-	yazi_config::init();
+	yazi_shared::init();
+
+	yazi_config::init()?;
 
 	yazi_adaptor::init();
 
 	yazi_boot::init();
 
-	yazi_plugin::init();
-
 	yazi_proxy::init();
 
+	yazi_dds::init();
+
+	yazi_plugin::init();
+
 	yazi_core::init();
 
+	yazi_dds::serve();
 	app::App::serve().await
 }
