@@ -1,7 +1,7 @@
 use ratatui::{buffer::Buffer, layout::Rect, widgets::{Block, BorderType, List, ListItem, Widget}};
 use yazi_config::THEME;
 
-use crate::{widgets, Ctx};
+use crate::Ctx;
 
 pub(crate) struct Select<'a> {
 	cx: &'a Ctx,
@@ -29,7 +29,7 @@ impl<'a> Widget for Select<'a> {
 			})
 			.collect();
 
-		widgets::Clear.render(area, buf);
+		yazi_plugin::elements::Clear::default().render(area, buf);
 		List::new(items)
 			.block(
 				Block::bordered()
