@@ -3,7 +3,7 @@ local M = {}
 function M:peek()
 	local _, bound = ya.preview_archive(self)
 	if bound then
-		ya.manager_emit("peek", { bound, only_if = tostring(self.file.url), upper_bound = true })
+		ya.manager_emit("peek", { bound, only_if = self.file.url, upper_bound = true })
 	end
 end
 
@@ -13,7 +13,7 @@ function M:seek(units)
 		local step = math.floor(units * self.area.h / 10)
 		ya.manager_emit("peek", {
 			math.max(0, cx.active.preview.skip + step),
-			only_if = tostring(self.file.url),
+			only_if = self.file.url,
 		})
 	end
 end
