@@ -3,20 +3,20 @@ use tokio::runtime::Handle;
 use yazi_config::LAYOUT;
 
 use super::slim_lua;
-use crate::{bindings::{Cast, File}, elements::Rect, LOADED};
+use crate::{bindings::{Cast, File}, elements::Rect, loader::LOADER};
 
 pub async fn preload(
 	name: &str,
 	files: Vec<yazi_shared::fs::File>,
 	multi: bool,
 ) -> mlua::Result<u8> {
-	LOADED.ensure(name).await.into_lua_err()?;
+	LOADER.ensure(name).await.into_lua_err()?;
 
 	let name = name.to_owned();
 	tokio::task::spawn_blocking(move || {
 		let lua = slim_lua(&name)?;
-		let plugin: Table = if let Some(b) = LOADED.read().get(&name) {
-			lua.load(b).call(())?
+		let plugin: Table = if let Some(b) = LOADER.read().get(&name) {
+			lua.load(b.as_ref()).call(())?
 		} else {
 			return Err("unloaded plugin".into_lua_err());
 		};
