@@ -26,11 +26,26 @@ pub struct FileOpPaste {
 	pub id:     usize,
 	pub from:   Url,
 	pub to:     Url,
+	pub meta:   Option<Metadata>,
 	pub cut:    bool,
 	pub follow: bool,
 	pub retry:  u8,
 }
 
+impl FileOpPaste {
+	pub(super) fn spawn(&self, from: Url, to: Url, meta: Metadata) -> Self {
+		Self {
+			id: self.id,
+			from,
+			to,
+			meta: Some(meta),
+			cut: self.cut,
+			follow: self.follow,
+			retry: self.retry,
+		}
+	}
+}
+
 #[derive(Clone, Debug)]
 pub struct FileOpLink {
 	pub id:       usize,
@@ -42,6 +57,20 @@ pub struct FileOpLink {
 	pub delete:   bool,
 }
 
+impl From<FileOpPaste> for FileOpLink {
+	fn from(value: FileOpPaste) -> Self {
+		Self {
+			id:       value.id,
+			from:     value.from,
+			to:       value.to,
+			meta:     value.meta,
+			resolve:  true,
+			relative: false,
+			delete:   value.cut,
+		}
+	}
+}
+
 #[derive(Clone, Debug)]
 pub struct FileOpDelete {
 	pub id:     usize,
