@@ -1,12 +1,13 @@
 use std::{collections::VecDeque, ffi::OsString};
 
 use crossterm::event::KeyEvent;
-use tokio::sync::{mpsc, oneshot};
+use tokio::sync::mpsc;
 
 use super::Cmd;
-use crate::{term::Term, Layer, RoCell};
+use crate::{Layer, RoCell};
 
 static TX: RoCell<mpsc::UnboundedSender<Event>> = RoCell::new();
+static RX: RoCell<mpsc::UnboundedReceiver<Event>> = RoCell::new();
 
 #[derive(Debug)]
 pub enum Event {
@@ -27,16 +28,17 @@ pub struct EventQuit {
 
 impl Event {
 	#[inline]
-	pub fn init(tx: mpsc::UnboundedSender<Event>) { TX.init(tx); }
+	pub fn init() {
+		let (tx, rx) = mpsc::unbounded_channel();
+		TX.init(tx);
+		RX.init(rx);
+	}
+
+	#[inline]
+	pub fn take() -> mpsc::UnboundedReceiver<Event> { RX.drop() }
 
 	#[inline]
 	pub fn emit(self) { TX.send(self).ok(); }
-
-	#[inline]
-	pub async fn wait<T>(self, rx: oneshot::Receiver<T>) -> T {
-		TX.send(self).ok();
-		rx.await.unwrap_or_else(|_| Term::goodbye(|| false))
-	}
 }
 
 #[macro_export]
