@@ -3,7 +3,6 @@
 mod chars;
 mod condition;
 mod debounce;
-mod defer;
 mod env;
 mod errors;
 pub mod event;
@@ -14,6 +13,7 @@ mod number;
 mod os;
 mod ro_cell;
 pub mod term;
+pub mod theme;
 mod throttle;
 mod time;
 mod xdg;
@@ -21,7 +21,6 @@ mod xdg;
 pub use chars::*;
 pub use condition::*;
 pub use debounce::*;
-pub use defer::*;
 pub use env::*;
 pub use errors::*;
 pub use layer::*;
@@ -32,3 +31,5 @@ pub use ro_cell::*;
 pub use throttle::*;
 pub use time::*;
 pub use xdg::*;
+
+pub fn init() { event::Event::init(); }
